@@ -25,6 +25,7 @@ def get_form_fields(input_pdf_path):
         Path to the pdf you want the fields from.
     Returns
     ---------
+    A dictionary of form fields and their filled values.
     """
     data_dict = {}
 
@@ -45,6 +46,21 @@ def get_form_fields(input_pdf_path):
                                     data_dict[key] = pdfrw.objects.PdfString.decode(annotation[ANNOT_VAL_KEY])
                             except:
                                 pass
+    return data_dict
+
+
+def print_form_fields(input_pdf_path):
+    """
+    Retrieves the form fields from get_form_fields(), then pretty prints
+    the data_dict. Uses pdfrw.
+    Parameters
+    ---------
+    input_pdf_path: str
+        Path to the pdf you want the fields from.
+    Returns
+    ---------
+    """
+    data_dict = get_form_fields(input_pdf_path)
     print("{" + ",\n".join("{!r}: {!r}".format(k, v) for k, v in data_dict.items()) + "}")
 
 
